==> jc-1.4.0.tar.gz: java/lang/VMString.h <==
// final class java.lang.VMString

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4bf65894ae9af31d java_lang_VMString

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMString_H_
#define _JC_java_lang_VMString_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_WeakHashMap$object;

// Typedefs
typedef struct _jc_java_lang_VMString$sub_refs	_jc_java_lang_VMString$sub_refs;
typedef struct _jc_java_lang_VMString$sub_nonrefs	_jc_java_lang_VMString$sub_nonrefs;
typedef struct _jc_java_lang_VMString$refs	_jc_java_lang_VMString$refs;
typedef struct _jc_java_lang_VMString$nonrefs	_jc_java_lang_VMString$nonrefs;
typedef struct _jc_java_lang_VMString$object	_jc_java_lang_VMString$object;

typedef struct _jc_java_lang_VMString$fields_struct	_jc_java_lang_VMString$fields_struct;
typedef const struct _jc_java_lang_VMString$vmethods	_jc_java_lang_VMString$vmethods;
typedef const struct _jc_java_lang_VMString$vtable	_jc_java_lang_VMString$vtable;
typedef const struct _jc_java_lang_VMString$vtype	_jc_java_lang_VMString$vtype;

// Class fields structure
struct _jc_java_lang_VMString$fields_struct {
	struct _jc_java_util_WeakHashMap$object	*internTable;
};
extern _jc_java_lang_VMString$fields_struct _jc_java_lang_VMString$class_fields;

// Constructors
extern void _jc_java_lang_VMString$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMString$object *);

// Static methods
extern void _jc_java_lang_VMString$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_java_lang_VMString$method$intern$d704e0dabc0fade6(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_VMString$vmethods {
};

// Vtable
struct _jc_java_lang_VMString$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMString$vmethods	java_lang_VMString;
};

// Vtype
struct _jc_java_lang_VMString$vtype {
	_jc_type			type;
	_jc_java_lang_VMString$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMString$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMString$refs {
    _jc_java_lang_VMString$sub_refs	java_lang_VMString;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMString$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMString$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMString$sub_nonrefs	java_lang_VMString;
};

// Object instance structure
struct _jc_java_lang_VMString$object {
	_jc_java_lang_VMString$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMString$vtype	*vtype;
	_jc_java_lang_VMString$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMString$vtype _jc_java_lang_VMString$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMString, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMString$class_object;

#endif	/* _JC_java_lang_VMString_H_ */

==> jc-1.4.6.tar.gz: java/lang/VMString.h <==
// final class java.lang.VMString

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4bf65894ae9af31d java_lang_VMString

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMString_H_
#define _JC_java_lang_VMString_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_WeakHashMap$object;

// Typedefs
typedef struct _jc_java_lang_VMString$sub_refs	_jc_java_lang_VMString$sub_refs;
typedef struct _jc_java_lang_VMString$sub_nonrefs	_jc_java_lang_VMString$sub_nonrefs;
typedef struct _jc_java_lang_VMString$refs	_jc_java_lang_VMString$refs;
typedef struct _jc_java_lang_VMString$nonrefs	_jc_java_lang_VMString$nonrefs;
typedef struct _jc_java_lang_VMString$object	_jc_java_lang_VMString$object;

typedef struct _jc_java_lang_VMString$fields_struct	_jc_java_lang_VMString$fields_struct;
typedef const struct _jc_java_lang_VMString$vmethods	_jc_java_lang_VMString$vmethods;
typedef const struct _jc_java_lang_VMString$vtable	_jc_java_lang_VMString$vtable;
typedef const struct _jc_java_lang_VMString$vtype	_jc_java_lang_VMString$vtype;

// Class fields structure
struct _jc_java_lang_VMString$fields_struct {
	struct _jc_java_util_WeakHashMap$object	*internTable;
};
extern _jc_java_lang_VMString$fields_struct _jc_java_lang_VMString$class_fields;

// Constructors
extern void _jc_java_lang_VMString$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMString$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_lang_VMString$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_lang_VMString$method$intern$d704e0dabc0fade6(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VMString$vmethods {
};

// Vtable
struct _jc_java_lang_VMString$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMString$vmethods	java_lang_VMString;
};

// Vtype
struct _jc_java_lang_VMString$vtype {
	_jc_type			type;
	_jc_java_lang_VMString$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMString$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMString$refs {
    _jc_java_lang_VMString$sub_refs	java_lang_VMString;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMString$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMString$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMString$sub_nonrefs	java_lang_VMString;
};

// Object instance structure
struct _jc_java_lang_VMString$object {
	_jc_java_lang_VMString$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMString$vtype	*vtype;
	_jc_java_lang_VMString$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMString$vtype _jc_java_lang_VMString$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMString, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMString$class_object;

#endif	/* _JC_java_lang_VMString_H_ */
